==> cirq_unstable-0.7.0.dev20191121170219-py3-none-any.whl: cirq/google/__init__.py <==
# Copyright 2018 The Cirq Developers
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     https://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

from cirq.google import api

from cirq.google.api.v1.params import (
    sweep_to_proto_dict,
    sweep_from_proto_dict,
)

from cirq.google.api.v1.programs import (
    gate_to_proto_dict,
    is_native_xmon_gate,
    is_native_xmon_op,
    pack_results,
    schedule_from_proto_dicts,
    schedule_to_proto_dicts,
    unpack_results,
    xmon_op_from_proto_dict,
)

from cirq.google.devices import (
    Bristlecone,
    Foxtail,
    SerializableDevice,
    Sycamore,
    Sycamore23,
    XmonDevice,
)

from cirq.google.engine import (
    Calibration,
    Engine,
    engine_from_environment,
    EngineJob,
    EngineProgram,
    JobConfig,
    ProtoVersion,
    QuantumEngineSampler,
)

from cirq.google.gate_sets import (
    XMON,
    SQRT_ISWAP_GATESET,
    SYC_GATESET,
)

from cirq.google.line import (
    AnnealSequenceSearchStrategy,
    GreedySequenceSearchStrategy,
    line_on_device,
    LinePlacementStrategy,
)

from cirq.google.ops.sycamore_gate import (
    SycamoreGate,
    SYC,
)

from cirq.google.optimizers import (
    ConvertToXmonGates,
    optimized_for_xmon,
)

from cirq.google.op_deserializer import (
    DeserializingArg,
    GateOpDeserializer,
)

from cirq.google.op_serializer import (
    GateOpSerializer,
    SerializingArg,
)

from cirq.google.serializable_gate_set import (
    SerializableGateSet,)

==> cirq_unstable-0.8.0.dev20200225195346-py3-none-any.whl: cirq/google/__init__.py <==
# Copyright 2018 The Cirq Developers
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     https://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

from cirq.google import api

from cirq.google.api.v1.programs import (
    is_native_xmon_gate,
    is_native_xmon_op,
    pack_results,
    unpack_results,
)

from cirq.google.devices import (
    Bristlecone,
    Foxtail,
    SerializableDevice,
    Sycamore,
    Sycamore23,
    XmonDevice,
)

from cirq.google.engine import (
    Calibration,
    Engine,
    engine_from_environment,
    EngineJob,
    EngineProgram,
    EngineProcessor,
    ProtoVersion,
    QuantumEngineSampler,
)

from cirq.google.gate_sets import (
    XMON,
    SQRT_ISWAP_GATESET,
    SYC_GATESET,
)

from cirq.google.line import (
    AnnealSequenceSearchStrategy,
    GreedySequenceSearchStrategy,
    line_on_device,
    LinePlacementStrategy,
)

from cirq.google.ops import (
    PhysicalZTag,
    SycamoreGate,
    SYC,
)

from cirq.google.optimizers import (
    ConvertToXmonGates,
    ConvertToSqrtIswapGates,
    ConvertToSycamoreGates,
    optimized_for_sycamore,
    optimized_for_xmon,
)

from cirq.google.op_deserializer import (
    DeserializingArg,
    GateOpDeserializer,
)

from cirq.google.op_serializer import (
    GateOpSerializer,
    SerializingArg,
)

from cirq.google.serializable_gate_set import (
    SerializableGateSet,)
